summaryrefslogtreecommitdiffstats
path: root/kexi/kexidb/object.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/kexidb/object.h')
-rw-r--r--kexi/kexidb/object.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/kexi/kexidb/object.h b/kexi/kexidb/object.h
index aff98491..232535d1 100644
--- a/kexi/kexidb/object.h
+++ b/kexi/kexidb/object.h
@@ -23,7 +23,7 @@
#include <kexidb/error.h>
#include <kmessagebox.h>
#include <kstdguiitem.h>
-#include <qstring.h>
+#include <tqstring.h>
namespace KexiDB {
@@ -39,7 +39,7 @@ class KEXI_DB_EXPORT Object
/*! \return (localized) error message if there was error during last operation on the object,
else: 0. */
- const QString& errorMsg() const { return m_errMsg; }
+ const TQString& errorMsg() const { return m_errMsg; }
/*! \return error number of if there was error during last operation on the object,
else: 0. */
@@ -48,7 +48,7 @@ class KEXI_DB_EXPORT Object
//! \return previous server result number, for error displaying purposes.
int previousServerResult() const { return m_previousServerResultNum; }
- QString previousServerResultName() const { return m_previousServerResultName; }
+ TQString previousServerResultName() const { return m_previousServerResultName; }
/*! Sends errorMsg() to debug output. */
void debugError();
@@ -71,7 +71,7 @@ class KEXI_DB_EXPORT Object
- default implementation just returns null string.
\sa serverErrorMsg()
*/
- virtual QString serverErrorMsg();
+ virtual TQString serverErrorMsg();
/*! \return engine-specific last server-side operation result number.
Use this in your application to give users more information on what's up.
@@ -93,16 +93,16 @@ class KEXI_DB_EXPORT Object
by serverErorMsg() or erorMsg()
\sa serverErrorMsg(), drv_clearServerResult()
*/
- virtual QString serverResultName();
+ virtual TQString serverResultName();
/*! \return message title that sometimes is provided and prepended
to the main warning/error message. Used by MessageHandler. */
- QString msgTitle() const { return m_msgTitle; }
+ TQString msgTitle() const { return m_msgTitle; }
/*! \return sql string of actually executed SQL statement,
usually using drv_executeSQL(). If there was error during executing SQL statement,
before, that string is returned instead. */
- const QString recentSQLString() const { return m_errorSql.isEmpty() ? m_sql : m_errorSql; }
+ const TQString recentSQLString() const { return m_errorSql.isEmpty() ? m_sql : m_errorSql; }
protected:
/* Constructs a new object.
@@ -118,34 +118,34 @@ class KEXI_DB_EXPORT Object
and default message for this will be set.
Use this in KexiDB::Object subclasses to informa the world about your
object's state. */
- virtual void setError(int code = ERR_OTHER, const QString &msg = QString::null );
+ virtual void setError(int code = ERR_OTHER, const TQString &msg = TQString() );
- /*! \overload void setError(int code, const QString &msg = QString::null )
+ /*! \overload void setError(int code, const TQString &msg = TQString() )
Sets error code to ERR_OTHER. Use this if you don't care about
setting error code.
*/
- virtual void setError( const QString &msg );
+ virtual void setError( const TQString &msg );
- /*! \overload void setError(const QString &msg)
+ /*! \overload void setError(const TQString &msg)
Also sets \a title. */
- virtual void setError( const QString &title, const QString &msg );
+ virtual void setError( const TQString &title, const TQString &msg );
/*! Copies the (localized) error message and code from other KexiDB::Object. */
- void setError( KexiDB::Object *obj, const QString& prependMessage = QString::null );
+ void setError( KexiDB::Object *obj, const TQString& prependMessage = TQString() );
/*! Copies the (localized) error message and code from other KexiDB::Object
with custom error \a code. */
virtual void setError( KexiDB::Object *obj, int code,
- const QString& prependMessage = QString::null );
+ const TQString& prependMessage = TQString() );
/*! Interactively asks a question. Console or GUI can be used for this,
depending on installed message handler. For GUI version, KMessageBox class is used.
See KexiDB::MessageHandler::askQuestion() for details. */
- virtual int askQuestion( const QString& message,
+ virtual int askQuestion( const TQString& message,
KMessageBox::DialogType dlgType, KMessageBox::ButtonCode defaultResult,
const KGuiItem &buttonYes=KStdGuiItem::yes(),
const KGuiItem &buttonNo=KStdGuiItem::no(),
- const QString &dontShowAskAgainName = QString::null,
+ const TQString &dontShowAskAgainName = TQString(),
int options = KMessageBox::Notify,
MessageHandler* msgHandler = 0 );
@@ -158,10 +158,10 @@ class KEXI_DB_EXPORT Object
virtual void drv_clearServerResult() {};
//! used to store of actually executed SQL statement
- QString m_sql, m_errorSql;
+ TQString m_sql, m_errorSql;
int m_serverResult;
- QString m_serverResultName, m_serverErrorMsg;
- QString m_errMsg;
+ TQString m_serverResultName, m_serverErrorMsg;
+ TQString m_errMsg;
private:
int m_errno;
@@ -170,9 +170,9 @@ class KEXI_DB_EXPORT Object
//! previous server result number, for error displaying purposes.
int m_previousServerResultNum, m_previousServerResultNum2;
//! previous server result name, for error displaying purposes.
- QString m_previousServerResultName, m_previousServerResultName2;
+ TQString m_previousServerResultName, m_previousServerResultName2;
- QString m_msgTitle;
+ TQString m_msgTitle;
MessageHandler *m_msgHandler;
class Private;